@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 # The MIT License
 #
 # Copyright (c) 2013 Sebastian Ramacher
@@ -22,10 +20,9 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from __future__ import absolute_import
-
 import sys
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     from . import main
+
     sys.exit(main())
