@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 # The MIT License
 #
 # Copyright (c) 2008 Bob Farrell
@@ -22,38 +20,37 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from __future__ import print_function
-
 import pdb
 import bpython
 
 
 class BPdb(pdb.Pdb):
-    """ PDB with BPython support. """
+    """PDB with BPython support."""
 
     def __init__(self, *args, **kwargs):
-        pdb.Pdb.__init__(self, *args, **kwargs)
-        self.prompt = '(BPdb) '
+        super().__init__(*args, **kwargs)
+        self.prompt = "(BPdb) "
         self.intro = 'Use "B" to enter bpython, Ctrl-d to exit it.'
 
     def postloop(self):
         # We only want to show the intro message once.
         self.intro = None
-        pdb.Pdb.postloop(self)
+        super().postloop()
 
     # cmd.Cmd commands
 
     def do_Bpython(self, arg):
         locals_ = self.curframe.f_globals.copy()
         locals_.update(self.curframe.f_locals)
-        bpython.embed(locals_, ['-i'])
-
+        bpython.embed(locals_, ["-i"])
 
     def help_Bpython(self):
         print("B(python)")
         print("")
-        print("Invoke the bpython interpreter for this stack frame. To exit "
-              "bpython and return to a standard pdb press Ctrl-d")
+        print(
+            "Invoke the bpython interpreter for this stack frame. To exit "
+            "bpython and return to a standard pdb press Ctrl-d"
+        )
 
     # shortcuts
     do_B = do_Bpython
