@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 # The MIT License
 #
 # Copyright (c) 2008 Simon de Vlieger
@@ -22,57 +20,59 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from __future__ import absolute_import
-
 import string
-from six.moves import range
+from typing import TypeVar, Generic, Tuple, Dict
+
+T = TypeVar("T")
 
 
-class KeyMap(object):
-
-    def __init__(self, default=''):
-        self.map = {}
+class KeyMap(Generic[T]):
+    def __init__(self, default: T) -> None:
+        self.map: Dict[str, T] = {}
         self.default = default
 
-    def __getitem__(self, key):
+    def __getitem__(self, key: str) -> T:
         if not key:
             # Unbound key
             return self.default
         elif key in self.map:
             return self.map[key]
         else:
-            raise KeyError('Configured keymap (%s)' % key +
-                           ' does not exist in bpython.keys')
+            raise KeyError(
+                f"Configured keymap ({key}) does not exist in bpython.keys"
+            )
 
-    def __delitem__(self, key):
+    def __delitem__(self, key: str):
         del self.map[key]
 
-    def __setitem__(self, key, value):
+    def __setitem__(self, key: str, value: T):
         self.map[key] = value
 
 
-cli_key_dispatch = KeyMap(tuple())
-urwid_key_dispatch = KeyMap('')
+cli_key_dispatch: KeyMap[Tuple[str, ...]] = KeyMap(tuple())
+urwid_key_dispatch = KeyMap("")
 
 # fill dispatch with letters
 for c in string.ascii_lowercase:
-    cli_key_dispatch['C-%s' % c] = (chr(string.ascii_lowercase.index(c) + 1),
-                                    '^%s' % c.upper())
+    cli_key_dispatch[f"C-{c}"] = (
+        chr(string.ascii_lowercase.index(c) + 1),
+        f"^{c.upper()}",
+    )
 
 for c in string.ascii_lowercase:
-    urwid_key_dispatch['C-%s' % c] = 'ctrl %s' % c
-    urwid_key_dispatch['M-%s' % c] = 'meta %s' % c
+    urwid_key_dispatch[f"C-{c}"] = f"ctrl {c}"
+    urwid_key_dispatch[f"M-{c}"] = f"meta {c}"
 
 # fill dispatch with cool characters
-cli_key_dispatch['C-['] = (chr(27), '^[')
-cli_key_dispatch['C-\\'] = (chr(28), '^\\')
-cli_key_dispatch['C-]'] = (chr(29), '^]')
-cli_key_dispatch['C-^'] = (chr(30), '^^')
-cli_key_dispatch['C-_'] = (chr(31), '^_')
+cli_key_dispatch["C-["] = (chr(27), "^[")
+cli_key_dispatch["C-\\"] = (chr(28), "^\\")
+cli_key_dispatch["C-]"] = (chr(29), "^]")
+cli_key_dispatch["C-^"] = (chr(30), "^^")
+cli_key_dispatch["C-_"] = (chr(31), "^_")
 
 # fill dispatch with function keys
 for x in range(1, 13):
-    cli_key_dispatch['F%d' % x] = ('KEY_F(%d)' % x,)
+    cli_key_dispatch[f"F{x}"] = (f"KEY_F({x})",)
 
 for x in range(1, 13):
-    urwid_key_dispatch['F%d' % x] = 'f%d' % x
+    urwid_key_dispatch[f"F{x}"] = f"f{x}"
